/**
 * @module Files
 * @license MIT
 * @author nuintun
 */
import { Context } from 'koa';
export interface Options {
  etag?: boolean;
  cacheControl?: string;
  acceptRanges?: boolean;
  lastModified?: boolean;
  ignore?: (path: string) => boolean;
}
/**
 * @class Files
 */
export default class Files {
  private root;
  private options;
  /**
   * @constructor
   * @description Create files service
   * @param root Files service root
   * @param options Files service options
   */
  constructor(root: string, options?: Options);
  /**
   * @private
   * @method isConditionalGET
   * @description Check if request is conditional GET
   * @param context Koa context
   */
  private isConditionalGET;
  /**
   * @private
   * @method isPreconditionFailure
   * @description Check if request precondition failure
   * @param context Koa context
   */
  private isPreconditionFailure;
  /**
   * @private
   * @method isRangeFresh
   * @description Check if request range fresh
   * @param context Koa context
   */
  private isRangeFresh;
  /**
   * @private
   * @method isIgnore
   * @description Check if path is ignore
   * @param path File path
   */
  private isIgnore;
  /**
   * @private
   * @method parseRange
   * @description Parse range
   * @param context Koa context
   * @param stats File stats
   */
  private parseRange;
  /**
   * @private
   * @method setupHeaders
   * @description Setup headers
   * @param context Koa context
   * @param path File path
   * @param stats File stats
   */
  private setupHeaders;
  /**
   * @private
   * @method read
   * @description Read file
   * @param path File path
   * @param range Read range
   * @param buffer Destination stream
   * @param end Is destory destination stream after read
   */
  private read;
  /**
   * @private
   * @method send
   * @description Send file
   * @param context Koa context
   * @param path File path
   * @param ranges Read ranges
   */
  private send;
  /**
   * @public
   * @method response
   * @description Response to koa context
   * @param context Koa context
   */
  response(context: Context): Promise<boolean>;
}
