/**
 * @module utils
 * @license MIT
 * @author nuintun
 */
/// <reference types="node" />
import { Stats } from 'fs';
/**
 * @function isOutRoot
 * @description Check if path is out of root
 * @param path The path to check
 * @param root The root path
 */
export declare function isOutRoot(path: string, root: string): boolean;
/**
 * @function unixify
 * @description Convert path to unix style
 * @param path The path to convert
 */
export declare function unixify(path: string): string;
/**
 * @function decodeURI
 * @description Decode URI component
 * @param URI The URI to decode
 */
export declare function decodeURI(URI: string): string | -1;
/**
 * @function boundaryGenerator
 * @description Generate a boundary
 */
export declare function boundaryGenerator(): string;
/**
 * @function fstat
 * @description Get file stats
 * @param path The file path
 */
export declare function fstat(path: string): Promise<Stats>;
/**
 * @function hasTrailingSlash
 * @description Check if path has trailing slash
 * @param path The path to check
 */
export declare function hasTrailingSlash(path: string): boolean;
/**
 * @function parseTokens
 * @description Parse HTTP tokens
 * @param value The tokens value string
 */
export declare function parseTokens(value: string): string[];
/**
 * @function isETag
 * @description Check if etag is valid
 * @param value The value to check
 */
export declare function isETag(value: string): boolean;
/**
 * @function isETagFresh
 * @description Check if etag is fresh
 * @param match The match value
 * @param etag The etag value
 */
export declare function isETagFresh(match: string, etag: string): boolean;
